@@ -9,6 +9,7 @@
 #include <vector>
 #include <unordered_set>
 #include <cstdint>
+#include <cstdlib>
 #include <fstream>
 #include <iterator>
 
@@ -19,6 +20,7 @@ private:
   std::string tar_path_;
   std::string map_path_;
   std::string out_path_ = "/dev/stdout";
+  std::string temp_prefix_;
   std::string prefix_; // deprecated
   std::string emp_out_path_;
   std::string sites_out_path_;
@@ -31,6 +33,7 @@ private:
   std::int64_t chunk_size_ = 20000000;
   std::int64_t overlap_ = 3000000;
   std::int16_t threads_ = 1;
+  float decay_ = 0.f;
   float min_r2_ = -1.f;
   float min_ratio_ = 1e-5f;
   float prob_threshold_ = 0.01f;
@@ -56,6 +59,7 @@ public:
   const std::string& out_path() const { return out_path_; }
   const std::string& emp_out_path() const { return emp_out_path_; }
   const std::string& sites_out_path() const { return sites_out_path_; }
+  const std::string& temp_prefix() const { return temp_prefix_; }
   savvy::file::format out_format() const { return out_format_; }
   std::uint8_t out_compression() const { return out_compression_; }
   const std::vector<std::string>& fmt_fields() const { return fmt_fields_; }
@@ -65,6 +69,7 @@ public:
   std::int64_t overlap() const { return overlap_; }
   std::int16_t threads() const { return threads_; }
   std::size_t temp_buffer() const { return temp_buffer_ ; }
+  float decay() const { return decay_; }
   float min_r2() const { return min_r2_; }
   float min_ratio() const { return min_ratio_; }
   float prob_threshold() const { return prob_threshold_; }
@@ -79,7 +84,9 @@ public:
 
   prog_args() :
     getopt_wrapper(
-      "Usage: minimac4 [opts ...] <reference.msav> <target.{sav,bcf,vcf.gz}>",
+      "Usage: minimac4 [opts ...] <reference.msav> <target.{sav,bcf,vcf.gz}>\n"
+      "       minimac4 [opts ...] --update-m3vcf <reference.m3vcf.gz>\n"
+      "       minimac4 [opts ...] --compress-reference <reference.{sav,bcf,vcf.gz}>",
       {
         {"all-typed-sites", no_argument, 0, 'a', "Include in the output sites that exist only in target VCF"},
         {"temp-buffer", required_argument, 0, 'b', "Number of samples to impute before writing to temporary files (default: 200)"},
@@ -89,24 +96,26 @@ public:
         {"format", required_argument, 0, 'f', "Comma-separated list of format fields to generate (GT, HDS, DS, GP, or SD; default: HDS)"},
         {"map", required_argument, 0, 'm', "Genetic map file"},
         {"output", required_argument, 0, 'o', "Output path (default: /dev/stdout)"},
-        {"output-format", required_argument, 0, 'O', "Output file format (bcf, sav, vcf.gz, ubcf, usav, or vcf; default: bcf)"},
+        {"output-format", required_argument, 0, 'O', "Default output file format used for ambiguous filenames (bcf, sav, vcf.gz, ubcf, usav, or vcf; default: sav)"},
         //{"pass-only", no_argument, 0, 'p', "Only imports variants with FILTER column set to PASS"},
         {"region", required_argument, 0, 'r', "Genomic region to impute"},
         {"sites", required_argument, 0, 's', "Output path for sites-only file"},
         {"threads", required_argument, 0, 't', "Number of threads (default: 1)"},
         {"version", no_argument, 0, 'v', "Print version"},
         {"overlap", required_argument, 0, 'w', "Size (in base pairs) of overlap before and after impute region to use as input to HMM (default: 3000000)"},
+        {"decay", required_argument, 0, '\x02', "Decay rate for dosages in flanking regions (default: disabled with 0)"},
         {"min-r2", required_argument, 0, '\x02', "Minimum estimated r-square for output variants"},
         {"min-ratio", required_argument, 0, '\x02', "Minimum ratio of number of target sites to reference sites (default: 0.00001)"},
         {"match-error", required_argument, 0, '\x02', "Error parameter for HMM match probabilities (default: 0.01)"},
         {"min-recom", required_argument, 0, '\x02', "Minimum recombination probability (default: 0.00001)"},
         {"prob-threshold", required_argument, 0, '\x02', "Probability threshold used for template selection"},
-        {"prob-threshold-s1", required_argument, 0, '\x02', ""}, // "Probability threshold used for template selection in original state space"},
+        {"prob-threshold-s1", required_argument, 0, '\x02', "Probability threshold used for template selection in original state space"},
         {"diff-threshold", required_argument, 0, '\x02', "Probability diff threshold used in template selection"},
         {"sample-ids", required_argument, 0, '\x02', "Comma-separated list of sample IDs to subset from reference panel"},
         {"sample-ids-file", required_argument, 0, '\x02', "Text file containing sample IDs to subset from reference panel (one ID per line)"},
-        {"update-m3vcf", no_argument, 0, '\x01', nullptr},
-        {"compress-reference", no_argument, 0, '\x01', nullptr},
+        {"temp-prefix", required_argument, 0, '\x02', "Prefix path for temporary output files (default: ${TMPDIR}/m4_)"},
+        {"update-m3vcf", no_argument, 0, '\x01', "Converts M3VCF to MVCF (default output: /dev/stdout)"},
+        {"compress-reference", no_argument, 0, '\x01', "Compresses VCF to MVCF (default output: /dev/stdout)"},
         // vvvv deprecated vvvv //
         {"allTypedSites", no_argument, 0, '\x01', nullptr},
         {"rsid", no_argument, 0, '\x01', nullptr},
@@ -275,7 +284,12 @@ public:
       case '\x02':
         {
           std::string long_opt_str = std::string(long_options_[long_index].name);
-          if (long_opt_str == "min-r2")
+          if (long_opt_str == "decay")
+          {
+            decay_ = std::atof(optarg ? optarg : "");
+            break;
+          }
+          else if (long_opt_str == "min-r2")
           {
             min_r2_ = std::atof(optarg ? optarg : "");
             break;
@@ -305,6 +319,11 @@ public:
             prob_threshold_s1_ = std::min(1., std::atof(optarg ? optarg : ""));
             break;
           }
+          else if (long_opt_str == "temp-prefix")
+          {
+            temp_prefix_ = optarg ? optarg : "";
+            break;
+          }
           else if (long_opt_str == "diff-threshold")
           {
             diff_threshold_ = std::max(0., std::atof(optarg ? optarg : ""));
@@ -446,6 +465,22 @@ public:
         emp_out_path_ = prefix_ + ".empiricalDose." + suffix;
     }
 
+    if (temp_prefix_.empty())
+    {
+      char* tmpdir = std::getenv("TMPDIR");
+      if (tmpdir && strlen(tmpdir))
+      {
+        std::string p(tmpdir);
+        if (p.back() != '/')
+          p += '/';
+        temp_prefix_ = p + "m4_";
+      }
+      else
+      {
+        temp_prefix_ = "/tmp/m4_";
+      }
+    }
+
     if (!emp_out_path_.empty() && std::find(fmt_fields_.begin(), fmt_fields_.end(), "HDS") == fmt_fields_.end())
       fmt_fields_.emplace_back("HDS");
 
